/*
 * Copyright (C) 2021 Uniontech Technology Co., Ltd.
 *
 * Author:     yeshanshan <yeshanshan@uniontech.com>
 *
 * Maintainer: yeshanshan <yeshanshan@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "mainwindow.h"

#include <DApplication>
#include <DWidgetUtil>

DWIDGET_USE_NAMESPACE


int main(int argc, char *argv[])
{
    DApplication a(argc, argv);
    a.setApplicationVersion("1.0.0");
    a.setApplicationName("dde-dconfig-editor");
    a.setOrganizationName("deepin");
    a.setProductIcon(QIcon::fromTheme(APP_ICON));
    a.setWindowIcon(QIcon::fromTheme(APP_ICON));

    MainWindow window;
    window.show();

    Dtk::Widget::moveToCenter(&window);

    return a.exec();
}
